@@ -118,9 +118,14 @@ def rfmodel(inifile):
                     outputDf.loc[outputDf['rolling_match'] == True, currModelName] = 1
                 outputDf = outputDf.drop(['rolling_match'], axis=1)
         if pose_estimation_body_parts == '4' or pose_estimation_body_parts == '7' or pose_estimation_body_parts == '8' or pose_estimation_body_parts == '7':
-            mouse1size = (statistics.mean(outputDf['Mouse_1_nose_to_tail']))
-            mouse1Max = mouse1size * 8
-            outputDf['Scaled_movement_M1'] = (outputDf['Total_movement_all_bodyparts_M1'] / (mouse1Max))
+            try:
+                mouse1size = (statistics.mean(outputDf['Mouse_1_nose_to_tail']))
+                mouse1Max = mouse1size * 8
+                outputDf['Scaled_movement_M1'] = (outputDf['Total_movement_all_bodyparts_M1'] / (mouse1Max))
+            except:
+                mouse1size = (statistics.mean(outputDf['Mouse_nose_to_tail']))
+                mouse1Max = mouse1size * 8
+                outputDf['Scaled_movement_M1'] = (outputDf['Total_movement_all_bodyparts_M1'] / (mouse1Max))
 
         if pose_estimation_body_parts == '16' or pose_estimation_body_parts == '14':
             mouse1size = (statistics.mean(outputDf['Mouse_1_nose_to_tail']))
