@@ -168,7 +168,7 @@ def train_multimodel(configini):
         fname = os.path.join(ensemble_evaluations_out, str(classifierName) + '_' + str(savefile_no) +'_permutations_importances.csv')
         dfvals.to_csv(fname, index=False)
 
-    def LearningCurve(features, targetFrame, shuffle_splits, dataset_splits,savefile_no):
+    def LearningCurve(features, targetFrame, shuffle_splits, dataset_splits,savefileno):
         cv = ShuffleSplit(n_splits=shuffle_splits, test_size=train_test_size, random_state=0)
         model = RandomForestClassifier(n_estimators=RF_n_estimators, max_features=RF_max_features, n_jobs=-1, criterion=RF_criterion, min_samples_leaf=RF_min_sample_leaf, bootstrap=True, verbose=1)
         train_sizes, train_scores, test_scores = learning_curve(model, features, targetFrame, cv=cv, scoring='f1',shuffle=True, n_jobs=-1, train_sizes=np.linspace(0.01, 1.0, dataset_splits))
@@ -183,7 +183,7 @@ def train_multimodel(configini):
         learningCurve_df['Test_mean_f1'] = test_mean
         learningCurve_df['Train_std_f1'] = train_std
         learningCurve_df['Test_std_f1'] = test_std
-        fname = os.path.join(ensemble_evaluations_out, str(classifierName) + '_' + str(savefile_no) + '_learning_curve.csv')
+        fname = os.path.join(ensemble_evaluations_out, str(classifierName) + '_' + str(saveFileNo) + '_learning_curve.csv')
         learningCurve_df.to_csv(fname, index=False)
 
     #READ IN THE META FILES
